clear all;
close all;
%% constants rate for the OmpR~P production
v=8e1;
V_prime=7e-8;  %maximal dephosphorylation rate of OmpR~P
K=0.7e-6;   %dimentionless Michaelis-Menten phosphorylation constant
K_prime=9e-8;  %dimentionless Michaelis-Menten dephosphorylation constant
OmpR_t=6.8e-8; %total concentration of OmpR into the cell

%% Kinetic rate constants for the Cya gene expression
Vm  = 2e-9;    %maximal transcription rate for cya gene expression
k   = 1e-7;    %activation coefficient for cya gene expression
b_ac   = 2e-12;    %basal activity for cya synthesis  
d   = 6e-3;    %degradation coefficient for cya

%% Matrix initialization
OmpR_P=zeros(50,1);
dipeptide=zeros(50,1);
m=0;
for i=[0.1:0.1:5]
m=m+1;
dipeptide(m)=10^(i)*10^(-9); %dipeptide concentration
V=v*dipeptide(m);    %maximal phosphorylation rate of OmpR V=K*[dipeptide]
%% definition of the polynomials coefficients
a=V_prime-V;
b=V*OmpR_t-V*K_prime-V_prime*K-V_prime*OmpR_t;
c=V*K_prime*OmpR_t;
%% call the function Polynomials_solver in order to have [OmpR~P]
roots=Polynomials_solver(a,b,c);

%% We assign the positive root to OmpR~P concentration
if roots(1)>0
    OmpR_P(m)=roots(1);
else
    OmpR_P(m)=roots(2);
end
end
cya=Vm/d*(OmpR_P).^2/(k^2+(OmpR_P).^2)+b_ac/d;

figure(1);
%subplot(1,2,1);
semilogx(dipeptide,OmpR_P./OmpR_t);
title('[OmpR~P] / [OmpR_t]  VS  [dipeptide]')
xlabel('dipeptide initial concentration [M]')
ylabel('OmpR~P production rate [-]')

figure(2);
%subplot(1,2,2);
semilogx(dipeptide,cya);
title('[cya] VS [dipeptide]')
xlabel('dipeptide initial concentration [M]')
ylabel('cya production [M]')

