%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Signaling Module                                                        %
%version 1 23rd of September                                              %
%this m-file calls the function Polynomials solver and generates 2 plots  %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clear all;
close all;
%% constants rate for the OmpR* production
v=8e1;%this constant represents the ration of maximal phosphorylation rate 
      %to initial dipeptide concentration (chosen in the for loop
V_prime=7e-8;  %maximal dephosphorylation rate of OmpR~P
K=0.7e-6;   %dimentionless Michaelis-Menten phosphorylation constant
K_prime=9e-8;  %dimentionless Michaelis-Menten dephosphorylation constant
OmpR_t=6.8e-8; %total concentration of OmpR into the cell

%% Kinetic rate constants for the Cya gene expression
Vm  = 2e-9;    %maximal transcription rate for cya gene expression
k   = 1e-7;    %activation coefficient for cya gene expression
b_ac   = 2e-12;    %basal activity for AC synthesis  
d   = 6e-3;    %degradation coefficient for AC

%% Matrix initialization
OmpR_P=zeros(61,1);
dipeptide=zeros(61,1);
m=0;% the counter for the "for loop"
for i=[-2:0.1:4]
m=m+1;
dipeptide(m)=10^(i)*10^(-9); %dipeptide initial concentration chosen
V=v*dipeptide(m);    %maximal phosphorylation rate of OmpR V=K*[dipeptide]
%% definition of the polynomials coefficients
a=V_prime-V;
b=V*OmpR_t-V*K_prime-V_prime*K-V_prime*OmpR_t;
c=V*K_prime*OmpR_t;
%% call the function Polynomials_solver in order to have [OmpR*]
roots=Polynomials_solver(a,b,c);

%% We assign the positive root to OmpR* concentration
if i>=0 
if roots(1)>0
    OmpR_P(m)=roots(1);
else
    OmpR_P(m)=roots(2);
end
else%this part is because of the parameters value chosen (V'-V) 
    %becomes positive under a given concentration of dipeptide 10^(-9)
    %we hope we can finally fix the parameters with the biologists
    %experiments
    OmpR_P(m)=roots(2);
end
end

cya=Vm/d*(OmpR_P).^2/(k^2+(OmpR_P).^2)+b_ac/d;%we assign here the value of
                                              %[AC]at the steady state    

figure(1);% we plot the curve of evolution of OmpR*
semilogx(dipeptide,OmpR_P./OmpR_t);
title('Ratio of [OmpR*] to [OmpR]tot VS initial dipeptide concentration')
xlabel('dipeptide initial concentration (Mol.L^-^1)')
ylabel('[OmpR~P] / [OmpR_t] ratio (-)')

figure(2);
semilogx(dipeptide,cya);
title('AC concentration VS initial dipeptide concentration')
xlabel('dipeptide initial concentration (Mol.L^-^1)')
ylabel('AC concentration (Mol.L^-^1)')

